"""wargame.__init__ 

This module is compatible with Python 3.5.x. It contains
supporting code for the book, Learning Python Application Development,
Packt Publishing.

:copyright: 2016, Ninad Sathaye

:license: The MIT License (MIT) . See LICENSE file for further details.
"""


import sys
import os
current_path = os.path.dirname(os.path.abspath(__file__))
sys.path.append(current_path)

# print("in __init__.py sys.path:\n ",sys.path)


